from django_celery_beat.models import IntervalSchedule, PeriodicTask, CrontabSchedule
from django.db import DEFAULT_DB_ALIAS
from django.apps import apps as global_apps


def initialize_task(app_config, verbosity=2, interactive=True, using=DEFAULT_DB_ALIAS, apps=global_apps, **kwargs):
    # Automatically register the utility periodic tasks
    PeriodicTask.objects.get_or_create(
        task="wbhuman_resources.tasks.create_future_public_holiday",
        defaults={
            "name": "HR: Create future public holiday",
            "crontab": CrontabSchedule.objects.get_or_create(
                minute="0",
                hour="6",
                day_of_month="1",
                month_of_year="*",
                day_of_week="*",
            )[
                0
            ],  # every first of the month at 6am utc
            "interval": None,
        },
    )



from django.apps import apps
from django.db import connection
from django.db.models.signals import pre_migrate
from pytest_factoryboy import register
from wbcore.contrib.authentication.factories import (
    AuthenticatedPersonFactory,
    InternalUserFactory,
    SuperUserFactory,
    UserFactory,
)
from wbcore.contrib.directory.factories import (
    AddressContactFactory,
    BankingContactFactory,
    ClientFactory,
    ClientManagerRelationshipFactory,
    CompanyFactory,
    CompanyTypeFactory,
    CustomerStatusFactory,
    EmailContactFactory,
    EmployersCompanyFactory,
    EntryFactory,
    PersonFactory,
    RelationshipFactory,
    RelationshipTypeFactory,
    TelephoneContactFactory,
    UnemployedPersonFactory,
    WebsiteContactFactory,
)
from wbcore.contrib.geography.factories import ContinentFactory, CountryFactory
from wbcore.contrib.geography.tests.signals import (
    app_pre_migration as app_pre_migration_geography,
)
from wbhuman_resources.factories import (
    AbsenceRequestFactory,
    AbsenceRequestPeriodsFactory,
    AbsenceRequestTypeFactory,
    BalanceHourlyAllowanceFactory,
    BaseDayOffCalendarFactory,
    DayOffCalendarFactory,
    DayOffFactory,
    DefaultDailyPeriodFactory,
    EmployeeHumanResourceFactory,
    EmployeeWeeklyOffPeriodsFactory,
    EmployeeYearBalanceFactory,
    PositionFactory,
    TimeOffRequestFactory,
    TimeOffTypeFactory,
    VacationRequestFactory,
    VacationTypeFactory,
)

register(DayOffCalendarFactory)
register(BaseDayOffCalendarFactory, "day_off_calendar_without_period"),
register(DayOffFactory)
register(EmployeeHumanResourceFactory)
register(EmployeeYearBalanceFactory)
register(AbsenceRequestFactory)
register(TimeOffRequestFactory, "time_off_request")
register(VacationRequestFactory, "vacation_request")
register(VacationTypeFactory, "time_off_type")
register(TimeOffTypeFactory, "vacation_type")
register(AbsenceRequestPeriodsFactory)
register(AbsenceRequestTypeFactory)
register(PositionFactory)
register(DefaultDailyPeriodFactory)
register(BalanceHourlyAllowanceFactory)
register(EmployeeWeeklyOffPeriodsFactory)

register(EntryFactory)
register(CompanyFactory)
register(PersonFactory)
register(ClientFactory)
register(InternalUserFactory)
register(UnemployedPersonFactory)
register(AuthenticatedPersonFactory)
register(EmployersCompanyFactory)
register(BankingContactFactory)
register(AddressContactFactory)
register(TelephoneContactFactory)
register(EmailContactFactory)
register(WebsiteContactFactory)
register(ClientManagerRelationshipFactory)
register(RelationshipFactory)
register(RelationshipTypeFactory)
register(CustomerStatusFactory)
register(CompanyTypeFactory)
register(ContinentFactory)
register(CountryFactory, "country")

register(AuthenticatedPersonFactory, "authenticated_person")
register(UserFactory)
register(SuperUserFactory, "superuser")
from .signals import app_pre_migration as app_pre_migration

pre_migrate.connect(app_pre_migration, sender=apps.get_app_config("wbhuman_resources"))
pre_migrate.connect(app_pre_migration_geography, sender=apps.get_app_config("geography"))



from django.utils.translation import gettext as _
from wbcore.menus import ItemPermission, MenuItem

from wbhuman_resources.models.absence import get_valid_employee_human_resource

ABSENCEPLANNER_MENUITEM = MenuItem(
    label=_("Absence Graph"),
    endpoint="wbhuman_resources:absenceplanner-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_absencerequest"]
    ),
)

ABSENCETABLE_MENUITEM = MenuItem(
    label=_("Presence Table"),
    endpoint="wbhuman_resources:absencetable-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_absencerequest"]
    ),
)

ABSENCEREQUEST_MENUITEM = MenuItem(
    label=_("Requests"),
    endpoint="wbhuman_resources:absencerequest-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_absencerequest"]
    ),
    add=MenuItem(
        label=_("Add Requests"),
        endpoint="wbhuman_resources:absencerequest-list",
        permission=ItemPermission(
            method=lambda request: request.user.is_internal
            and get_valid_employee_human_resource(request.user) is not None,
            permissions=["wbhuman_resources.add_absencerequest"],
            include_superuser=False,
        ),
    ),
)

ABSENCEREQUESTTYPE_MENUITEM = MenuItem(
    label=_("Request Types"),
    endpoint="wbhuman_resources:absencerequesttype-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_absencerequesttpe"]
    ),
    add=MenuItem(
        label=_("Add Request Types"),
        endpoint="wbhuman_resources:absencerequesttype-list",
        permission=ItemPermission(
            method=lambda request: request.user.is_internal,
            permissions=["wbhuman_resources.add_absencerequesttype"],
        ),
    ),
)



from django.utils.translation import gettext as _
from wbcore.menus import ItemPermission, MenuItem

KPI_MENUITEM = MenuItem(
    label=_("KPIs"),
    endpoint="wbhuman_resources:kpi-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_kpi"]
    ),
)
KPIEVALUATIONPANDAS_MENUITEM = MenuItem(
    label=_("KPI Evaluations"),
    endpoint="wbhuman_resources:kpievaluationpandas-list",
    permission=ItemPermission(
        method=lambda request: request.user.is_internal, permissions=["wbhuman_resources.view_kpi"]
    ),
)



# Generated by Django 5.2.9 on 2025-12-16 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wbhuman_resources', '0023_alter_employeehumanresource_weekly_off_periods'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='absencerequestperiods',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='balancehourlyallowance',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='dayoffcalendar',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='employeeweeklyoffperiods',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='employeeyearbalance',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='balancehourlyallowance',
            constraint=models.UniqueConstraint(fields=('balance', 'period_index'), name='unique_balanceallowance'),
        ),
        migrations.AddConstraint(
            model_name='dayoffcalendar',
            constraint=models.UniqueConstraint(fields=('resource', 'timezone'), name='unique_calendar'),
        ),
        migrations.AddConstraint(
            model_name='employeeweeklyoffperiods',
            constraint=models.UniqueConstraint(fields=('employee', 'period', 'weekday'), name='unique_weeklyoffperiod'),
        ),
        migrations.AddConstraint(
            model_name='employeeyearbalance',
            constraint=models.UniqueConstraint(fields=('employee', 'year'), name='unique_employeeyearbalance'),
        ),
    ]



from __future__ import absolute_import, unicode_literals

from datetime import date, datetime, timedelta
from io import BytesIO

import pandas as pd
from celery import shared_task
from django.core.mail import EmailMultiAlternatives
from django.db.models import Q
from django.template.loader import get_template
from django.utils.translation import gettext
from django.utils.translation import gettext_lazy as _
from dynamic_preferences.registries import global_preferences_registry
from wbcore.contrib.directory.models import Person
from wbcore.contrib.notifications.dispatch import send_notification
from wbcore.utils.date import current_month_date_end
from wbcore.utils.html import convert_html2text
from wbcore.workers import Queue

from wbhuman_resources.models import KPI, DayOffCalendar, EmployeeHumanResource, Review

from .models.preferences import get_previous_year_balance_expiration_date
from .signals import add_employee_activity_to_daily_brief


@shared_task(queue=Queue.BACKGROUND.value)
def create_future_public_holiday(today: date | None = None, forecast_year: int = 5):
    if not today:
        today = date.today()
    for calendar in DayOffCalendar.objects.all():
        for year in range(today.year, today.year + forecast_year):
            calendar.create_public_holidays(year)


@shared_task(queue=Queue.BACKGROUND.value)
def assign_balance(today=None):
    """
    Yearly periodic cron tasks that increase for an employee
    """
    if not today:
        today = datetime.now().date()

    for employee in EmployeeHumanResource.active_internal_employees.all():
        [start_period, end_period] = EmployeeHumanResource.ExtraDaysBalanceFrequency[
            employee.extra_days_frequency
        ].get_date_range(today)
        employee.assign_vacation_allowance_from_range(start_period.date(), end_period.date())


@shared_task(queue=Queue.BACKGROUND.value)
def check_and_warn_user_with_previous_year_available_balance(year=None):
    """
    When this task run, it will send a reminder Notification to user with still available balance for the previous year
    """
    if not year:
        year = date.today().year

    for employee in EmployeeHumanResource.active_internal_employees.all():
        previous_year_balance = employee.get_or_create_balance(year - 1)[0]
        if (previous_year_remaining_days := previous_year_balance.total_vacation_hourly_balance) > 0:
            send_notification(
                code="wbhuman_resources.employeehumanresource.vacation",
                title=_("You still have {} hours of vacation to take from {}").format(
                    previous_year_remaining_days, year - 1
                ),
                body=_(
                    "Please take vacation from now to {:%d.%m.%Y} (excluded). Your balance will not be available after that date"
                ).format(get_previous_year_balance_expiration_date(year=year)),
                user=employee.profile.user_account,
            )


@shared_task(queue=Queue.BACKGROUND.value)
def send_mail_to_accounting():
    global_preferences = global_preferences_registry.manager()
    accounting_company_emails = list(
        filter(None, global_preferences["wbhuman_resources__accounting_company_emails"].split(";"))
    )
    cc_emails = list(EmployeeHumanResource.get_administrators().values_list("email", flat=True))

    end_of_month = current_month_date_end()

    output = BytesIO()
    EmployeeHumanResource.get_end_of_month_employee_balance_report_df(
        EmployeeHumanResource.active_internal_employees.all(), end_of_month
    ).to_excel(output, engine="xlsxwriter", index=False)

    html = get_template("notifications/email_template.html")

    notification = {
        "message": gettext(
            "Please find the vacation days balance valid to the end of the month as attached excel file"
        ),
        "title": gettext("Vacation balance summary at {:%d.%m.%Y}").format(end_of_month),
    }
    html_content = html.render({"notification": notification})
    mail_text = convert_html2text(html_content)
    msg = EmailMultiAlternatives(
        gettext("Vacation Report {:%d.%m.%Y}").format(end_of_month),
        body=mail_text,
        from_email=global_preferences["wbhuman_resources__default_from_email_address"],
        to=accounting_company_emails,
        cc=cc_emails,
    )
    msg.attach_alternative(html_content, "text/html")
    output.seek(0)
    msg.attach(
        "vacation_report_{:%m-%d-%Y}.xlsx".format(end_of_month),
        output.read(),
        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
    )
    msg.send()


@shared_task(queue=Queue.BACKGROUND.value)
def daily_automatic_application_deadline():
    for review in Review.objects.filter(
        Q(status=Review.Status.FILL_IN_REVIEW) & Q(review_deadline__lte=datetime.now().date())
    ):
        review.save()

    week = datetime.now().date() - timedelta(days=7)
    for review in Review.objects.filter(Q(status=Review.Status.FILL_IN_REVIEW) & Q(review_deadline=week)):
        persons = [review.reviewee, review.reviewer]
        for person in persons:
            if hasattr(person, "user_account"):
                msg = gettext("Dear {} {}, <p>you only have one more week to complete the review.</p>").format(
                    person.first_name, person.last_name
                )
                review.send_review_notification(
                    title=gettext("Stage 2: Fill in review - {}").format(str(review)),
                    message=msg,
                    recipient=person.user_account,
                )

    # Daily notification
    for review in Review.objects.filter(
        Q(status=Review.Status.FILL_IN_REVIEW) & Q(review_deadline=datetime.now().date() - timedelta(days=1))
    ):
        persons = [review.reviewee, review.reviewer]
        for person in persons:
            if hasattr(person, "user_account"):
                msg = gettext("Dear {} {}, <p>you only have one more day to complete the review.</p>").format(
                    person.first_name, person.last_name
                )

                review.send_review_notification(
                    title=gettext("Stage 2: Fill in review - {}").format(str(review)),
                    message=msg,
                    recipient=person.user_account,
                )


@shared_task(queue=Queue.BACKGROUND.value)
def periodic_updating_kpi_task(kpi_id: list | None = None, start=None, end=None):
    intervals = {elt.name: KPI.Interval.get_frequence_correspondance(elt.name) for elt in KPI.Interval}
    for key, value in intervals.items():
        kpis = (
            KPI.objects.filter(id__in=kpi_id, evaluated_intervals=key)
            if kpi_id
            else KPI.objects.filter(evaluated_intervals=key, is_active=True)
        )
        for kpi in kpis:
            if not start:
                start = kpi.period.lower
            if not end:
                end = kpi.period.upper
            for date_evaluation in pd.date_range(start=start, end=end, freq=value):
                kpi.generate_evaluation(date_evaluation.date())


@shared_task(queue=Queue.BACKGROUND.value)
def daily_brief(today: date | None = None, **kwargs):
    """Creates a summary of the daily brief for all internal employees
    Args:
        today (date | None, optional): Date of today. Defaults to None.
    """

    if not today:
        today = date.today()
    for employee in EmployeeHumanResource.active_internal_employees.filter(profile__user_account__isnull=False):
        daily_brief = ""
        for receiver, res in add_employee_activity_to_daily_brief.send(  # noqa: B007
            sender=Person, instance=employee.profile, val_date=today, **kwargs
        ):
            if res:
                title, html = res
                daily_brief += f"<h2 text-align: center;>{title}</h2>\n<div style='margin-bottom: 1.5em; text-align: left;'>{html}</div>\n"

        if daily_brief:
            send_notification(
                code="wbcrm.activity.daily_brief",
                title=_("Your Daily Brief"),
                body=daily_brief,
                user=employee.profile.user_account,
            )



# Generated by Django 4.2.9 on 2024-02-20 10:08

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wbhuman_resources", "0018_remove_position_group_position_groups"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="absencerequest",
            options={
                "permissions": [("administrate_absencerequest", "Can Administrate Absence Requests")],
                "verbose_name": "Absence Request",
                "verbose_name_plural": "Absence Requests",
            },
        ),
        migrations.AlterModelOptions(
            name="kpi",
            options={
                "permissions": [("administrate_kpi", "Can Administrate KPI")],
                "verbose_name": "Key Performance Indicator",
                "verbose_name_plural": "Key Performance Indicators",
            },
        ),
        migrations.AlterModelOptions(
            name="review",
            options={
                "permissions": [("administrate_review", "Can Administrate Reviews")],
                "verbose_name": "Review",
                "verbose_name_plural": "Reviews",
            },
        ),
        migrations.AlterModelOptions(
            name="employeehumanresource",
            options={
                "permissions": [("administrate_employeehumanresource", "Can administrate Employee Human Resource")],
                "verbose_name": "Employee Human Resource",
                "verbose_name_plural": "Employee Human Resources",
            },
        ),
    ]



from django.apps import AppConfig, apps
from django.db.models.signals import post_migrate


class WbhumanResourcesConfig(AppConfig):
    name = "wbhuman_resources"

    def ready(self) -> None:
        from wbcore.signals.filters import add_filters

        from wbhuman_resources.management import initialize_task

        from .filters.signals import add_position_filter

        if apps.is_installed("wbcrm"):
            from wbcrm.filters import ActivityFilter

            add_filters.connect(add_position_filter, sender=ActivityFilter)

        post_migrate.connect(
            initialize_task,
            dispatch_uid="wbhuman_resources.initialize_task",
        )



from .absence import (
    AbsenceRequestCrossBorderCountryEndpointConfig,
    AbsenceRequestEndpointConfig,
    AbsenceRequestPeriodsAbsenceRequestEndpointConfig,
    AbsenceRequestPlannerEndpointConfig,
    AbsenceTablePandasEndpointConfig,
    AbsenceTypeCountEmployeeEndpointConfig,
)
from .calendars import (
    DayOffDayOffCalendarEndpointConfig,
    DefaultDailyPeriodDayOffCalendar,
)
from .employee import (
    AbsenceRequestEmployeeHumanResourceEndpointConfig,
    EmployeeBalanceEndpointConfig,
    EmployeeEndpointConfig,
    WeeklyOffPeriodEmployeeHumanResourceEndpointConfig,
    YearBalanceEmployeeHumanResourceEndpointConfig,
)
from .kpis import (
    EvaluationGraphEndpointConfig,
    KPIEndpointConfig,
    KPIEvaluationEndpointConfig,
    KPIEvaluationPandasEndpointConfig,
)
from .review import (
    ReviewAnswerReviewPandasEndpointConfig,
    ReviewAnswerEndpointConfig,
    ReviewAnswerReviewNoCategoryEndpointConfig,
    ReviewAnswerReviewQuestionCategoryEndpointConfig,
    ReviewEndpointConfig,
    ReviewGroupEndpointConfig,
    ReviewProgressPandasEndpointConfig,
    ReviewProgressReviewPandasEndpointConfig,
    ReviewQuestionCategoryEndpointConfig,
    ReviewQuestionEndpointConfig,
    ReviewQuestionReviewCategoryEndpointConfig,
    ReviewQuestionReviewEndpointConfig,
    ReviewQuestionReviewNoCategoryEndpointConfig,
    ReviewQuestionReviewQuestionCategoryEndpointConfig,
    ReviewReviewGroupEndpointConfig,
)



from django.utils.translation import gettext_lazy as _
from rest_framework.reverse import reverse
from wbcore import serializers
from wbcore.contrib.directory.serializers import PersonRepresentationSerializer

from wbhuman_resources.models import KPI, Evaluation


class KPIRepresentationSerializer(serializers.RepresentationSerializer):
    _detail = serializers.HyperlinkField(reverse_name="wbhuman_resources:kpi-detail")

    class Meta:
        model = KPI
        fields = ("id", "name", "_detail")


class EvaluationRepresentationSerializer(serializers.RepresentationSerializer):
    _person = PersonRepresentationSerializer(source="person")

    class Meta:
        model = Evaluation
        fields = ("id", "evaluated_score", "person", "_person", "evaluation_date")


class KPIModelSerializer(serializers.ModelSerializer):
    handler = serializers.ChoiceField(choices=list(KPI.get_all_handler_choices()), label=_("Handler"))
    parameters = serializers.ListField(read_only=True)
    _evaluated_persons = PersonRepresentationSerializer(source="evaluated_persons", many=True)

    @serializers.register_resource()
    def register_history_resource(self, instance, request, user):
        resources = {
            "evaluations": reverse("wbhuman_resources:kpi-evaluation-list", args=[instance.id], request=request),
            "evaluationgraph": reverse(
                "wbhuman_resources:kpi-evaluationgraph-list", args=[instance.id], request=request
            ),
            "kpievaluationpandas": reverse("wbhuman_resources:kpievaluationpandas-list", args=[], request=request)
            + f"?kpi={instance.id}",
        }

        return resources

    class Meta:
        model = KPI
        fields = (
            "id",
            "name",
            "handler",
            "goal",
            "period",
            "evaluated_intervals",
            "evaluated_persons",
            "_evaluated_persons",
            "parameters",
            "last_update",
            "individual_evaluation",
            "is_active",
            "_additional_resources",
        )


class EvaluationModelSerializer(serializers.ModelSerializer):
    _kpi = KPIRepresentationSerializer(source="kpi")
    _person = PersonRepresentationSerializer(source="person")
    goal = serializers.IntegerField(read_only=True)

    class Meta:
        model = Evaluation
        fields = (
            "id",
            "kpi",
            "_kpi",
            "person",
            "_person",
            "evaluated_score",
            "evaluated_period",
            "evaluation_date",
            "last_update",
            "goal",
        )



#!/usr/bin/env python3

from django.urls import include, path
from wbcore.routers import WBCoreRouter

from wbhuman_resources import viewsets

router = WBCoreRouter()


# Calendar viewsets

router.register(
    "defaultdailyperiodrepresentation",
    viewsets.DefaultDailyPeriodRepresentationViewSet,
    basename="defaultdailyperiodrepresentation",
)
router.register(
    "employeeweeklyoffperiodrepresentation",
    viewsets.EmployeeWeeklyOffPeriodsRepresentationViewSet,
    basename="employeeweeklyoffperiodrepresentation",
)
router.register("dayoffrepresentation", viewsets.DayOffRepresentationViewSet, basename="dayoffrepresentation")
router.register(
    "dayoffcalendarrepresentation",
    viewsets.DayOffCalendarRepresentationViewSet,
    basename="dayoffcalendarrepresentation",
)

router.register("dayoffcalendar", viewsets.DayOffCalendarModelViewSet, basename="dayoffcalendar")
router.register("dayoff", viewsets.DayOffModelViewSet, basename="dayoff")

calendar_router = WBCoreRouter()
calendar_router.register("dayoff", viewsets.DayOffDayOffCalendarModelViewSet, basename="calendar-dayoff")
calendar_router.register(
    "defaultperiod", viewsets.DefaultDailyPeriodDayOffCalendarModelViewSet, basename="calendar-defaultperiod"
)

# absence request type router
absencerequesttype_router = WBCoreRouter()
absencerequesttype_router.register(
    "crossbordercountry",
    viewsets.AbsenceRequestCrossBorderCountryModelViewSet,
    basename="absencerequesttype-crossbordercountry",
)


# Employee routers
router.register(
    r"employeehumanresourcerepresentation",
    viewsets.EmployeeHumanResourceRepresentationViewSet,
    basename="employeehumanresourcerepresentation",
)
router.register(r"positionrepresentation", viewsets.PositionRepresentationViewSet, basename="positionrepresentation")
router.register(
    "employeeyearbalancerepresentation",
    viewsets.EmployeeYearBalanceRepresentationViewSet,
    basename="employeeyearbalancerepresentation",
)

router.register(r"employeebalance", viewsets.EmployeeBalanceModelViewSet, basename="employeebalance")
router.register(r"employee", viewsets.EmployeeModelViewSet, basename="employee")
router.register(r"position", viewsets.PositionModelViewSet, basename="position")


employee_router = WBCoreRouter()
employee_router.register(
    r"weeklyoffperiod",
    viewsets.WeeklyOffPeriodEmployeeHumanResourceModelViewSet,
    basename="employee-weeklyoffperiod",
)
employee_router.register(
    r"absence",
    viewsets.AbsenceTypeCountEmployeeModelViewSet,
    basename="employee-absencecount",
)

employee_router.register(
    r"absencerequest",
    viewsets.AbsenceRequestEmployeeHumanResourceModelViewset,
    basename="employee-absencerequest",
)
employee_router.register(
    r"employeeyearbalance",
    viewsets.YearBalanceEmployeeHumanResourceModelViewset,
    basename="employee-employeeyearbalance",
)

# Absence routers
router.register(
    r"absencerequesttyperepresentation",
    viewsets.AbsenceRequestTypeRepresentationViewSet,
    basename="absencerequesttyperepresentation",
)


router.register(r"absenceplanner", viewsets.AbsenceRequestPlanner, basename="absenceplanner")
router.register(r"absencerequest", viewsets.AbsenceRequestModelViewSet)
router.register(r"absencerequesttype", viewsets.AbsenceRequestTypeModelViewSet, basename="absencerequesttype")

absence_request_router = WBCoreRouter()
absence_request_router.register(
    r"periods",
    viewsets.AbsenceRequestPeriodsAbsenceRequestModelViewSet,
    basename="request-periods",
)

# Review Routers
router.register(r"reviewrepresentation", viewsets.ReviewRepresentationViewSet, basename="reviewrepresentation")
router.register(
    r"reviewgrouprepresentation", viewsets.ReviewGroupRepresentationViewSet, basename="reviewgrouprepresentation"
)
router.register(
    r"reviewquestioncategoryrepresentation",
    viewsets.ReviewQuestionCategoryRepresentationViewSet,
    basename="reviewquestioncategoryrepresentation",
)
router.register(
    r"reviewquestionrepresentation",
    viewsets.ReviewQuestionRepresentationViewSet,
    basename="reviewquestionrepresentation",
)

router.register(r"reviewgroup", viewsets.ReviewGroupModelViewSet, basename="reviewgroup")

router.register(r"review", viewsets.ReviewModelViewSet, basename="review")
router.register(r"reviewtemplate", viewsets.ReviewTemplateModelViewSet, basename="reviewtemplate")

router.register(
    r"reviewquestioncategory", viewsets.ReviewQuestionCategoryModelViewSet, basename="reviewquestioncategory"
)

router.register(r"reviewquestion", viewsets.ReviewQuestionModelViewSet, basename="reviewquestion")
router.register(r"reviewanswer", viewsets.ReviewAnswerModelViewSet, basename="reviewanswer")
router.register(r"absencetable", viewsets.AbsenceTablePandasViewSet, basename="absencetable")

reviewgroup_router = WBCoreRouter()
reviewgroup_router.register(r"review", viewsets.ReviewReviewGroupModelViewSet, basename="reviewgroup-review")

review_router = WBCoreRouter()
review_router.register(r"reviewquestion", viewsets.ReviewQuestionReviewModelViewSet, basename="review-reviewquestion")
review_router.register(
    r"reviewquestionnocategory",
    viewsets.ReviewQuestionReviewNoCategoryModelViewSet,
    basename="review-reviewquestionnocategory",
)
review_router.register(
    r"reviewanswerquestionnocategory",
    viewsets.ReviewAnswerReviewNoCategoryModelViewSet,
    basename="review-reviewanswerquestionnocategory",
)


review_category_router = WBCoreRouter()
review_category_router.register(
    r"reviewquestioncategory",
    viewsets.ReviewQuestionReviewCategoryModelViewSet,
    basename="review-reviewquestioncategory",
)
review_category_router.register(
    r"reviewanswerquestioncategory",
    viewsets.ReviewAnswerReviewQuestionCategoryModelViewSet,
    basename="review-reviewanswerquestioncategory",
)

review_question_category_router = WBCoreRouter()
review_question_category_router.register(
    r"reviewquestion",
    viewsets.ReviewQuestionReviewQuestionCategoryModelViewSet,
    basename="reviewquestioncategory-reviewquestion",
)

# KPI routers
router.register(r"kpi", viewsets.KPIModelViewSet, basename="kpi")
router.register(r"kpirepresentation", viewsets.KPIRepresentationViewSet, basename="kpirepresentation")
router.register(
    r"evaluationrepresentation", viewsets.EvaluationRepresentationViewSet, basename="evaluationrepresentation"
)

kpi_router = WBCoreRouter()

kpi_router.register(
    r"evaluation",
    viewsets.KPIEvaluationModelViewSet,
    basename="kpi-evaluation",
)
kpi_router.register(r"evaluationgraph", viewsets.EvaluationGraphChartViewset, basename="kpi-evaluationgraph")


# Review pandas views
router.register("reviewprogress", viewsets.ReviewProgressPandasViewSet, basename="reviewprogress")
router.register("kpievaluationpandas", viewsets.KPIEvaluationPandasViewSet, basename="kpievaluationpandas")
review_router.register(r"progress", viewsets.ReviewProgressReviewPandasViewSet, basename="review-progress")
review_router.register(
    r"reviewanswerpandasview", viewsets.ReviewAnswerReviewPandasViewSet, basename="review-reviewanswerpandasview"
)

urlpatterns = [
    path("", include(router.urls)),
    path(
        "absencerequesttype/<int:absencerequesttype_id>/",
        include(absencerequesttype_router.urls),
    ),
    path(
        "employee/<int:employee_id>/",
        include(employee_router.urls),
    ),
    path(
        "request/<int:request_id>/",
        include(absence_request_router.urls),
    ),
    path(
        "calendar/<int:calendar_id>/",
        include(calendar_router.urls),
    ),
    path("reviewgroup/<int:review_group_id>/", include(reviewgroup_router.urls)),
    path("review/<int:review_id>/", include(review_router.urls)),
    path("review/<int:review_id>/category/<int:category_id>/", include(review_category_router.urls)),
    path("reviewquestioncategory/<int:category_id>/", include(review_question_category_router.urls)),
    path("kpi/<int:kpi_id>/", include(kpi_router.urls)),
]



from .absence import (
    ABSENCEPLANNER_MENUITEM,
    ABSENCEREQUEST_MENUITEM,
    ABSENCEREQUESTTYPE_MENUITEM,
    ABSENCETABLE_MENUITEM,
)
from .administration import ADMINISTRATION_MENU
from .calendars import DAYOFF_MENUITEM, DAYOFFCALENDAR_MENUITEM
from .employee import (
    EMPLOYEE_MENUITEM,
    EMPLOYEEHUMANRESOURCE_MENUITEM,
    POSITION_MENUITEM,
)
from .kpis import KPI_MENUITEM, KPIEVALUATIONPANDAS_MENUITEM
from .review import (
    REVIEW_MENUITEM,
    REVIEWANDWER_MENUITEM,
    REVIEWGROUP_MENUITEM,
    REVIEWQUESTION_MENUITEM,
    REVIEWQUESTIONCATEFORY_MENUITEM,
    REVIEWTEMPLATE_MENUITEM,
)
